//  Nikita Golikov, 2023

#include <bits/stdc++.h>

using namespace std;

using uint = unsigned int;
using ll = long long;
using ull = unsigned long long;

#ifdef GOLIKOV
  #include "/Users/golikovnik/contests/debug.h"
#else
  #define debug(...) ;
#endif

template <class A, class B>
bool smin(A& x, B&& y) {
  if (y < x) {
    x = y;
    return true;
  }
  return false;
}

template <class A, class B>
bool smax(A& x, B&& y) {
  if (x < y) {
    x = y;
    return true;
  }
  return false;
}

template <class T>
struct SegmentTree {
  int pw;
  int n;

  vector<T> tree;

  template <class F = function<T(int)>>
  SegmentTree(int n_, F const& f) : n(n_) {
    pw = 1;
    while (pw < n) {
      pw *= 2;
    }
    tree.resize(2 * pw);
    for (int i = 0; i < n; ++i) {
      tree[pw + i] = f(i);
    }
    for (int i = pw - 1; i > 0; --i) {
      tree[i] = tree[2 * i] + tree[2 * i + 1];
    }
  }

  T query(int ql, int qr) {
    T L{}, R{};
    for (ql += pw, qr += pw; ql < qr; ql /= 2, qr /= 2) {
      if (ql & 1) {
        L = L + tree[ql++];
      }
      if (qr & 1) {
        R = tree[--qr] + R;
      }
    }
    return L + R;
  }

  template <class F>
  void modPoint(int at, F const& f) {
    for (f(tree[at += pw]); at /= 2; ) {
      tree[at] = tree[2 * at] + tree[2 * at + 1];
    }
  }

  struct FindResult {
    T val{};
    int pos = -1;
  };

  template <class F = function<bool(T)>>
  FindResult findFirst(int v, int l, int r, int ql, int qr, F const& f, T pref) {
    if (ql >= r || l >= qr) {
      return {pref, -1};
    }
    if (ql <= l && r <= qr) {
      if (!f(pref + tree[v])) {
        return {pref + tree[v], -1};
      }
      if (l + 1 == r) {
        return {pref + tree[v], l};
      }
      int m = (l + r) / 2;
      if (f(pref + tree[2 * v])) {
        return findFirst(2 * v, l, m, ql, qr, f, pref);
      } else {
        return findFirst(2 * v + 1, m, r, ql, qr, f, pref + tree[2 * v]);
      }
    } else {
      int m = (l + r) / 2;
      auto res = findFirst(2 * v, l, m, ql, qr, f, pref);
      if (res.pos == -1) {
        return findFirst(2 * v + 1, m, r, ql, qr, f, res.val);
      } else {
        return res;
      }
    }
  }  

  template <class F = function<bool(T)>>
  FindResult findFirst(int ql, int qr, F const& f) {
    return findFirst(1, 0, pw, ql, qr, f, T());
  }

  template <class F = function<bool(T)>>
  FindResult findLast(int v, int l, int r, int ql, int qr, F const& f, T suff) {
    if (ql >= r || l >= qr) {
      return {suff, -1};
    }
    if (ql <= l && r <= qr) {
      if (!f(tree[v] + suff)) {
        return {tree[v] + suff, -1};
      }
      if (l + 1 == r) {
        return {tree[v] + suff, l};
      }
      int m = (l + r) / 2;
      if (f(tree[2 * v + 1] + suff)) {
        return findLast(2 * v + 1, m, r, ql, qr, f, suff);
      } else {
        return findLast(2 * v, l, m, ql, qr, f, tree[2 * v + 1] + suff);
      }
    } else {
      int m = (l + r) / 2;
      auto res = findLast(2 * v + 1, m, r, ql, qr, f, suff);
      if (res.pos == -1) {
        return findLast(2 * v, l, m, ql, qr, f, res.val);
      } else {
        return res;
      }
    }
  }

  template <class F = function<bool(T)>>
  FindResult findLast(int ql, int qr, F const& f) {
    return findLast(1, 0, pw, ql, qr, f, T());
  }

  T all() {
    return tree[1];
  }
};

int main() {
#ifdef GOLIKOV
  assert(freopen("in", "rt", stdin));
  auto _clock_start = chrono::high_resolution_clock::now();
#endif
  ios::sync_with_stdio(false);
  cin.tie(nullptr);

  int n, q;
  cin >> n >> q;
  vector<int> w(n), d(n - 1);
  for (int& x : w) {
    cin >> x;
  }
  for (int& x : d) {
    cin >> x;
  }

  static ll const INF = ll(-1e18);
  struct T {
    array<array<ll, 2>, 2> dp;
    bool neutral;

    T() {
      dp[0][0] = dp[0][1] = dp[1][0] = dp[1][1] = INF;
      neutral = true;
    }

    T(ll edge, ll ver) : T() {
      //  close, close
      dp[0][0] = 0;
      //  close, open
      dp[0][1] = -ver;
      //  open, close
      dp[1][0] = edge - ver;
      //  open, open
      dp[1][1] = edge - ver;
      neutral = false;
    }

    T operator+(T const& other) const {
      if (neutral) return other;
      if (other.neutral) return *this;
      T res;
      res.neutral = false;
      for (int l = 0; l < 2; ++l) {
        for (int m = 0; m < 2; ++m) {
          for (int r = 0; r < 2; ++r) {
            smax(res.dp[l][r], dp[l][m] + other.dp[m][r]);
          }
        }
      }
      return res;
    }
  };
  SegmentTree<T> tree(n - 1, [&](int i) {
    return T(d[i], w[i + 1]);
  });

  while (q--) {
    int t; cin >> t;
    if (t == 1) {
      int i, x;
      cin >> i >> x;
      --i;
      w[i] = x;
      if (i > 0) {
        tree.modPoint(i - 1, [&](T& v) { v = T(d[i - 1], w[i]); });
      }
    } else if (t == 2) {
      int i, x;
      cin >> i >> x;
      --i;
      d[i] = x;
      tree.modPoint(i, [&](T& v) { v = T(d[i], w[i + 1]); });
    } else {
      int l, r, x;
      cin >> l >> r >> x;
      --l;
      auto res = tree.query(l, r - 1).dp;
      cout << max({res[0][0], res[1][0] - w[l], res[0][1] - w[l] + x, res[1][1] - w[l] + x}) << '\n';
    }
  }

#ifdef GOLIKOV
  cerr << "Executed in " << chrono::duration_cast<chrono::milliseconds>(
      chrono::high_resolution_clock::now()
          - _clock_start).count() << "ms." << endl;
#endif
  return 0;
}
