//  Nikita Golikov, 2023

#include <bits/stdc++.h>

using namespace std;

using uint = unsigned int;
using ll = long long;
using ull = unsigned long long;

#ifdef GOLIKOV
  #include "/Users/golikovnik/contests/debug.h"
#else
  #define debug(...) ;
#endif

template <class A, class B>
bool smin(A& x, B&& y) {
  if (y < x) {
    x = y;
    return true;
  }
  return false;
}

template <class A, class B>
bool smax(A& x, B&& y) {
  if (x < y) {
    x = y;
    return true;
  }
  return false;
}

template <class T, class M>
struct LazySegmentTree {
  int pw;
  int n;

  struct Node {
    T val{};
    M mod{};

    void apply(M const& x) {
      mod.apply(x);
      val.apply(x);
    }

    Node operator+(Node const& other) const {
      return Node{val + other.val};
    }
  };
  vector<Node> tree;

  template <class F>
  LazySegmentTree(int n_, F const& f) : n(n_) {
    pw = 1;
    while (pw < n) {
      pw *= 2;
    }
    tree.resize(2 * pw);
    for (int i = 0; i < n; ++i) {
      tree[pw + i].val = f(i);
    }
    for (int i = pw - 1; i > 0; --i) {
      tree[i] = tree[2 * i] + tree[2 * i + 1];
    }
  }

  void push(int v) {
    tree[2 * v].apply(tree[v].mod);
    tree[2 * v + 1].apply(tree[v].mod);
    tree[v].mod = M();
  }

  T query(int v, int l, int r, int ql, int qr) {
    if (ql >= r || l >= qr) {
      return T();
    }
    if (ql <= l && r <= qr) {
      return tree[v].val;
    }
    int m = (l + r) / 2;
    push(v);
    return query(2 * v, l, m, ql, qr) + query(2 * v + 1, m, r, ql, qr);
  }

  T query(int ql, int qr) {
    return query(1, 0, pw, ql, qr);
  }

  void modRange(int v, int l, int r, int ql, int qr, M const& mod) {
    if (ql >= r || l >= qr) {
      return;
    }
    if (ql <= l && r <= qr) {
      tree[v].apply(mod);
      return;
    }
    int m = (l + r) / 2;
    push(v);
    modRange(2 * v, l, m, ql, qr, mod);
    modRange(2 * v + 1, m, r, ql, qr, mod);
    tree[v] = tree[2 * v] + tree[2 * v + 1];
  }

  void modRange(int ql, int qr, M const& mod) {
    modRange(1, 0, pw, ql, qr, mod);
  }

  template <class F>
  void modPoint(int v, int l, int r, int at, F const& f) {
    if (l + 1 == r) {
      f(tree[v].val);
      return;
    }
    int m = (l + r) / 2;
    push(v);
    if (at < m) {
      modPoint(2 * v, l, m, at, f);
    } else {
      modPoint(2 * v + 1, m, r, at, f);
    }
    tree[v] = tree[2 * v] + tree[2 * v + 1];
  }

  template <class F>
  void modPoint(int at, F const& f) {
    modPoint(1, 0, pw, at, f);
  }

  void setPoint(int at, T const& t) {
    modPoint(at, [&](T& x) { x = t; });
  }

  struct FindResult {
    T val{};
    int pos = -1;
  };

  template <class F>
  FindResult findFirst(int v, int l, int r, int ql, int qr, F const& f, T pref) {
    if (ql >= r || l >= qr) {
      return {pref, -1};
    }
    if (ql <= l && r <= qr) {
      if (!f(pref + tree[v].val)) {
        return {pref + tree[v].val, -1};
      }
      if (l + 1 == r) {
        return {pref + tree[v].val, l};
      }
      int m = (l + r) / 2;
      push(v);
      if (f(pref + tree[2 * v].val)) {
        return findFirst(2 * v, l, m, ql, qr, f, pref);
      } else {
        return findFirst(2 * v + 1, m, r, ql, qr, f, pref + tree[2 * v].val);
      }
    } else {
      int m = (l + r) / 2;
      push(v);
      auto res = findFirst(2 * v, l, m, ql, qr, f, pref);
      if (res.pos == -1) {
        return findFirst(2 * v + 1, m, r, ql, qr, f, res.val);
      } else {
        return res;
      }
    }
  }  

  template <class F>
  FindResult findFirst(int ql, int qr, F const& f) {
    return findFirst(1, 0, pw, ql, qr, f, T());
  }

  template <class F>
  FindResult findLast(int v, int l, int r, int ql, int qr, F const& f, T suff) {
    if (ql >= r || l >= qr) {
      return {suff, -1};
    }
    if (ql <= l && r <= qr) {
      if (!f(tree[v].val + suff)) {
        return {tree[v].val + suff, -1};
      }
      if (l + 1 == r) {
        return {tree[v].val + suff, l};
      }
      int m = (l + r) / 2;
      push(v);
      if (f(tree[2 * v + 1].val + suff)) {
        return findLast(2 * v + 1, m, r, ql, qr, f, suff);
      } else {
        return findLast(2 * v, l, m, ql, qr, f, tree[2 * v + 1].val + suff);
      }
    } else {
      int m = (l + r) / 2;
      push(v);
      auto res = findLast(2 * v + 1, m, r, ql, qr, f, suff);
      if (res.pos == -1) {
        return findLast(2 * v, l, m, ql, qr, f, res.val);
      } else {
        return res;
      }
    }
  }

  template <class F>
  FindResult findLast(int ql, int qr, F const& f) {
    return findLast(1, 0, pw, ql, qr, f, T());
  }

  T all() {
    return tree[1].val;
  }
};

int main() {
#ifdef GOLIKOV
  assert(freopen("in", "rt", stdin));
  auto _clock_start = chrono::high_resolution_clock::now();
#endif
  ios::sync_with_stdio(false);
  cin.tie(nullptr);

  int n, q;
  cin >> n >> q;
  vector<int> w(n), d(n - 1);
  for (int& x : w) {
    cin >> x;
  }
  for (int& x : d) {
    cin >> x;
  }

  static ll const INF = ll(-1e18);
  struct M {
    void apply(M) {}
  };
  struct T {
    array<array<ll, 2>, 2> dp;
    bool neutral;

    T() {
      dp[0][0] = dp[0][1] = dp[1][0] = dp[1][1] = INF;
      neutral = true;
    }

    T(ll edge, ll ver) : T() {
      //  close, close
      dp[0][0] = 0;
      //  close, open
      dp[0][1] = -ver;
      //  open, close
      dp[1][0] = edge - ver;
      //  open, open
      dp[1][1] = edge - ver;
      neutral = false;
    }

    T operator+(T const& other) const {
      if (neutral) return other;
      if (other.neutral) return *this;
      T res;
      res.neutral = false;
      for (int l = 0; l < 2; ++l) {
        for (int m = 0; m < 2; ++m) {
          for (int r = 0; r < 2; ++r) {
            smax(res.dp[l][r], dp[l][m] + other.dp[m][r]);
          }
        }
      }
      return res;
    }

    void apply(M) {}
  };
  LazySegmentTree<T, M> tree(n - 1, [&](int i) {
    return T(d[i], w[i + 1]);
  });

  while (q--) {
    int t; cin >> t;
    if (t == 1) {
      int i, x;
      cin >> i >> x;
      --i;
      w[i] = x;
      if (i > 0) {
        tree.modPoint(i - 1, [&](T& v) { v = T(d[i - 1], w[i]); });
      }
    } else if (t == 2) {
      int i, x;
      cin >> i >> x;
      --i;
      d[i] = x;
      tree.modPoint(i, [&](T& v) { v = T(d[i], w[i + 1]); });
    } else {
      int l, r, x;
      cin >> l >> r >> x;
      --l;
      auto res = tree.query(l, r - 1).dp;
      cout << max({res[0][0], res[1][0] - w[l], res[0][1] - w[l] + x, res[1][1] - w[l] + x}) << '\n';
    }
  }

#ifdef GOLIKOV
  cerr << "Executed in " << chrono::duration_cast<chrono::milliseconds>(
      chrono::high_resolution_clock::now()
          - _clock_start).count() << "ms." << endl;
#endif
  return 0;
}
