#include <bits/stdc++.h>

using namespace std;

using ll = long long;

const char en = '\n';

template<typename T>
int sz(T x) { return (int)x.size(); }

#ifdef LOCAL
#include "debug.h"
#else
#define debug(...) 42
#endif

template<typename T>
struct Fenwick {
    int n;
    vector<T> f;

    Fenwick(int _n) {
        n = _n;
        f.assign(n + 1, 0);
    }

    void update(int x, T delta) {
        for (int i = x; i <= n; i += i & -i) {
            f[i] += delta;
        }
    }

    T get_sum(int x) {
        T s = 0;
        for (int i = x; i > 0; i -= i & -i) {
            s += f[i];
        }
        return s;
    }

    T get(int L, int R) { // [L, R]
        return get_sum(R) - get_sum(L - 1);
    }
};

void solve() {
    int n;
    string s;
    int q;
    cin >> n >> s >> q;
    Fenwick<int> count_a(n);
    for (int i = 0; i < n; ++i) {
        if (s[i] == 'a') {
            count_a.update(i + 1, 1);
        }
    }

    auto check_segment = [&](int l, int r) -> bool {
        int len = r - l + 1;
        int cnt_a = count_a.get(l + 1, r + 1);
        int cnt_b = len - cnt_a;
        return cnt_a >= cnt_b;
    };

    auto check_segment_seg = [&](pair<int, int> seg) -> bool {
        return check_segment(seg.first, seg.second);
    };

    set<pair<int, int>> all_segments; // [l, r] is b....b
    set<pair<int, int>> bad_segments; // [l, r] is b....b

    int last = 0;
    for (int i = 0; i < n; ++i) {
        if (s[i] == 'b' && (i != n - 1 && s[i + 1] == 'b')) {
            all_segments.emplace(last, i);
            if (!check_segment(last, i)) {
                bad_segments.emplace(last, i);
            }
            last = i + 1;
        }
    }
    all_segments.emplace(last, n - 1);
    if (!check_segment(last, n - 1)) {
        bad_segments.emplace(last, n - 1);
    }
    
    for (int w = 0; w < q; ++w) {
        int type;
        cin >> type;
        if (type == 1) {
            int i;
            cin >> i;
            --i;
            if (s[i] == 'a') {

                count_a.update(i + 1, -1);

                auto prev_seg = *prev(all_segments.upper_bound({i, n + 1}));
                if (0 <= i - 1 && s[i - 1] == 'b') {
                    all_segments.erase(prev_seg);
                    bad_segments.erase(prev_seg);
                    pair<int, int> new_seg1 = {prev_seg.first, i - 1};
                    pair<int, int> new_seg2 = {i, prev_seg.second};
                    all_segments.emplace(new_seg1);
                    all_segments.emplace(new_seg2);
                    if (!check_segment_seg(new_seg1)) {
                        bad_segments.emplace(new_seg1);
                    }
                    if (!check_segment_seg(new_seg2)) {
                        bad_segments.emplace(new_seg2);
                    }
                }
                
                prev_seg = *prev(all_segments.upper_bound({i, n + 1}));
                if (i + 1 < n && s[i + 1] == 'b') {
                    all_segments.erase(prev_seg);
                    bad_segments.erase(prev_seg);
                    pair<int, int> new_seg1 = {prev_seg.first, i};
                    pair<int, int> new_seg2 = {i + 1, prev_seg.second};
                    all_segments.emplace(new_seg1);
                    all_segments.emplace(new_seg2);
                    if (!check_segment_seg(new_seg1)) {
                        bad_segments.emplace(new_seg1);
                    }
                    if (!check_segment_seg(new_seg2)) {
                        bad_segments.emplace(new_seg2);
                    }
                }
                
                auto cur_seg = *prev(all_segments.upper_bound({i, n + 1}));
                bad_segments.erase(cur_seg);
                if (!check_segment_seg(cur_seg)) {
                    bad_segments.emplace(cur_seg);
                }
                
                s[i] = 'b';
            } else {
                count_a.update(i + 1, 1);
                
                if (0 <= i - 1 && s[i - 1] == 'b') {
                    auto prev_seg = *prev(all_segments.lower_bound({i, -1}));
                    auto cur_seg = *all_segments.lower_bound({i, -1});
                    all_segments.erase(prev_seg);
                    bad_segments.erase(prev_seg);
                    all_segments.erase(cur_seg);
                    bad_segments.erase(cur_seg);
                    pair<int, int> new_seg = {prev_seg.first, cur_seg.second};
                    all_segments.emplace(new_seg);
                    if (!check_segment_seg(new_seg)) {
                        bad_segments.emplace(new_seg);
                    }
                }
                
                if (i + 1 < n && s[i + 1] == 'b') {
                    auto cur_seg = *prev(all_segments.upper_bound({i, n + 1}));
                    if (all_segments.upper_bound({i, n + 1}) != all_segments.end()) {
                        auto next_seg = *all_segments.upper_bound({i, n + 1});
                        all_segments.erase(cur_seg);
                        bad_segments.erase(cur_seg);
                        all_segments.erase(next_seg);
                        bad_segments.erase(next_seg);

                        pair<int, int> new_seg = {cur_seg.first, next_seg.second};

                        all_segments.emplace(new_seg);
                        if (!check_segment_seg(new_seg)) {
                            bad_segments.emplace(new_seg);
                        }
                    }

                }
                
                auto cur_seg = *prev(all_segments.upper_bound({i, n + 1}));
                bad_segments.erase(cur_seg);
                if (!check_segment_seg(cur_seg)) {
                    bad_segments.emplace(cur_seg);
                }
                
                s[i] = 'a';
            }
        } else {
            int l, r;
            cin >> l >> r;
            --l; --r;
            bool ok = true;
            
            auto pref_seg = *prev(all_segments.lower_bound({l + 1, -1}));
            if (!check_segment(l, min(r, pref_seg.second))) {
                ok = false;
            }
            
            auto suf_seg = *prev(all_segments.lower_bound({r + 1, -1}));
            if (!check_segment(max(l, suf_seg.first), r)) {
                ok = false;
            }
            
            auto seg = bad_segments.lower_bound({l, -1});
            if (seg != bad_segments.end() && seg->second <= r) {
                ok = false;
            }
            
            cout << (ok ? "YES" : "NO") << en;
        }
    }
}

int32_t main() {
#ifdef THEEVILBIRD
    freopen("input.txt", "r", stdin);
#else
    ios_base::sync_with_stdio(0);
    cin.tie(0);
#endif
    solve();
    return 0;
}