#include <vector>
#include <iostream>
#include <set>
#include <map>
#include <algorithm>

using namespace std;

typedef long long ll;
typedef vector<ll> vll;
typedef vector<vll> vvll;

void dfs(int v, vector<vector<int>> &g, vector<int> &dp) {
    bool find = false;
    for (auto u : g[v]) {
        dfs(u, g, dp);
        dp[v] = max(dp[v], dp[u]);
        find |= (g[u].size() == 0);
    }
    if (find) {
        int mx = 0;
        for (auto u : g[v]) {
            if (g[u].size() != 0) {
                mx = max(mx, dp[u]);
            }
        }
        dp[v] = max(dp[v], mx + 1);
    }
}

void solve_b() {
    int n;
    cin >> n;
    vector<vector<int>> g(n);
    for (int v = 1; v < n; ++v) {
        int p;
        cin >> p;
        p--;
        g[p].push_back(v);
    }
    vector<int> dp (n, 0);
    dfs(0, g, dp);
    /*for (auto i : dp) {
        cout << i << ' ';
    }
    cout << '\n';*/
    cout << dp[0];
}

struct Node {
    int pref, suf, seg;
    int sz;

    Node(int pref = 0, int suf = 0, int seg = 0, int sz = 0) : pref(pref), suf(suf), seg(seg), sz(sz) {}

    Node operator+(const Node &node) const {
        Node sum(pref, node.suf, max(seg, node.seg), sz + node.sz);
         if (pref == sz) {
             sum.pref += node.pref;
         }
         if (node.suf == node.sz) {
             sum.suf += suf;
         }
         sum.seg = max({sum.seg, suf + node.pref, sum.pref, sum.suf});
         return sum;
    }
};

struct Flowers {
    Node a, b;
    int x, y;

    Flowers() : a(), b(), x(0), y(0) {}

    Flowers(char c) {
        x = (c == 'a');
        y = (c == 'b');
        a = Node(x, x, x, 1);
        b = Node(y, y, y, 1);
    }

    Flowers(Node a, Node b, int x, int y) : a(a), b(b), x(x), y(y) {}

    Flowers operator+(const Flowers &f) const {
        return {a + f.a, b + f.b, x + f.x, y + f.y};
    }
};

struct SegmentTree {
    vector<Flowers> data;
    string base;

    SegmentTree(string &s) : base(s), data(4 * (int) s.size()) {
        build(0, 0, (int) s.size());
    }

    void build(int v, int l, int r) {
        if (l + 1 == r) {
            data[v] = Flowers(base[l]);
            return;
        }
        int m = (l + r) / 2;
        build(2 * v + 1, l, m);
        build(2 * v + 2, m, r);
        data[v] = data[2 * v + 1] + data[2 * v + 2];
    }

    void update(int v, int l, int r, int p) {
        if (l + 1 == r) {
            if (base[l] == 'a') {
                base[l] = 'b';
            } else {
                base[l] = 'a';
            }
            data[v] = Flowers(base[l]);
            return;
        }
        int m = (l + r) / 2;
        if (p < m) {
            update(2 * v + 1, l, m, p);
        } else {
            update(2 * v + 2, m, r, p);
        }
        data[v] = data[2 * v + 1] + data[2 * v + 2];
    }

    Flowers get(int v, int l, int r, int lq, int rq) {
        if (rq <= l || r <= lq) {
            return {};
        }
        if (lq <= l && r <= rq) {
            return data[v];
        }
        int m = (l + r) / 2;
        Flowers p1 = get(2 * v + 1, l, m, lq, rq);
        Flowers p2 = get(2 * v + 2, m, r, lq, rq);
        return p1 + p2;
    }
};

void solve_l() {
    int n;
    cin >> n;
    string s;
    cin >> s;
    SegmentTree tree(s);
    int q;
    cin >> q;
    while (q--) {
        int type;
        cin >> type;
        if (type == 1) {
            int p;
            cin >> p;
            p--;
            tree.update(0, 0, n, p);
        } else {
            int l, r;
            cin >> l >> r;
            l--;
            Flowers f = tree.get(0, 0, n, l, r);
            if (f.b.seg >= 2 || f.b.seg == 1 && f.x < f.y) {
                cout << "NO\n";
            } else {
                cout << "YES\n";
            }
        }
    }
}

int main() {
    ios_base::sync_with_stdio(false), cin.tie(0);
    //COMMENTED
    int t = 1;
    //cin >> t;
    while(t--) {
        solve_l();
    }
    return 0;
}
