#include <bits/stdc++.h>
using namespace std;

struct segment_tree {
    struct node {
        bool full, full_l, full_r, full_lr;
        char first, last;
    };

    node merge(node a, node b) {
        node c;
        c.full = (a.full && b.full) || (a.full_r && b.full_l && (a.last != 'b' || b.first != 'b'));
        c.full_l = (a.full_l && b.full) || (a.full_lr && b.full_l && (a.last != 'b' || b.first != 'b'));
        c.full_r = (a.full && b.full_r) || (a.full_r && b.full_lr && (a.last != 'b' || b.first != 'b'));
        c.full_lr = (a.full_l && b.full_r) || (a.full_lr && b.full_lr && (a.last != 'b' || b.first != 'b'));
        c.first = a.first;
        c.last = a.last;
        return c;
    }

    int size;
    vector<node> tree;

    segment_tree(string s) {
        int n = (int) s.size();
        size = 2 << __lg(n);
        tree.resize(2 * size);
        for (int i = 0; i < n; i++) {
            tree[size + i] = {s[i] != 'b', true, true, true, s[i], s[i]};
        }
        for (int i = size - 1; i > 0; i--) {
            tree[i] = merge(tree[i * 2], tree[i * 2 + 1]);
        }
    }

    void modify(int i, char v) {
        modify(i, v, 1, 0, size);
    }

    void modify(int i, char v, int x, int lx, int rx) {
        if (rx - lx == 1) {
            tree[x] = {v != 'b', true, true, true, v, v};
        } else {
            int mid = (lx + rx) / 2;
            if (i < mid) {
                modify(i, v, x * 2, lx, mid);
            } else {
                modify(i, v, x * 2 + 1, mid, rx);
            }
            tree[x] = merge(tree[x * 2], tree[x * 2 + 1]);
        }
    }

    bool query(int l, int r) {
        return query(l, r, 1, 0, size).first.full;
    }

    pair<node, bool> query(int l, int r, int x, int lx, int rx) {
        if (lx >= r || rx <= l) {
            return {node(), false};
        } else if (lx >= l && rx <= r) {
            return {tree[x], true};
        } else {
            int mid = (lx + rx) / 2;
            auto [left, left_e] = query(l, r, x * 2, lx, mid);
            auto [right, right_e] = query(l, r, x * 2 + 1, mid, rx);
            if (left_e && right_e) {
                return {merge(left, right), true};
            } else if (left_e) {
                return {left, true};
            } else {
                return {right, true};
            }
        }
    }
};

int main() {
    cin.tie(nullptr)->sync_with_stdio(false);
    int n;
    string s;
    cin >> n >> s;
    int q;
    cin >> q;
    segment_tree ST(s);
    while (q--) {
        int type;
        cin >> type;
        if (type == 1) {
            int i;
            cin >> i;
            i--;
            ST.modify(i, s[i] = (s[i] == 'a' ? 'b' : 'a'));
        } else {
            int l, r;
            cin >> l >> r;
            l--;
            cout << (ST.query(l, r) ? "YES\n" : "NO\n");
        }
    }
}
