#include <iostream>
#include <map>
#include <algorithm>
#include <vector>
#include <set>

using namespace std;

#define int long long

struct node {
    int pref, suf, res, sum = 0;

    node() {
        pref = 0, suf = 0, res = 0, sum = 0;
    }

    node(int v) {
        pref = max(0ll, v), suf = max(0ll, v), res = max(0ll, v), sum = v;
    }
};

node operator+(node a, node b) {
    node x;
    x.pref = max(a.pref, a.sum + b.pref);
    x.suf = max(b.suf, a.suf + b.sum);
    x.res = max(a.res, b.res);
    x.res = max(x.res, a.suf + b.pref);
    x.sum = a.sum + b.sum;
    return x;
}

struct segment_tree {
    vector<node> tree;
    int n;

    segment_tree(int n_) {
        n = n_;
        tree.resize(4 * n);
    }

    node get(int v, int tl, int tr, int l, int r) {
        if (tr < l || r < tl)
            return node();
        if (l <= tl && tr <= r) {
            return tree[v];
        }
        int tm = (tl + tr) / 2;
        return get(v * 2, tl, tm, l, r) + get(v * 2 + 1, tm + 1, tr, l, r);
    }

    void upd(int v, int tl, int tr, int pos, int val) {
        if (tl == tr) {
            tree[v] = node(val);
            return;
        }
        int tm = (tl + tr) / 2;
        if (tm >= pos)
            upd(v * 2, tl, tm, pos, val);
        else
            upd(v * 2 + 1, tm + 1, tr, pos, val);
        tree[v] = tree[v * 2] + tree[v * 2 + 1];
//        if (v == 5) {
//            cout << tree[v * 2].suf << ' ' << tree[v * 2 + 1].suf << ' ' << tree[v * 2 + 1].sum << endl;
//            cout << tree[v].suf << endl;
//        }
    }

    void upd(int v, int l) {
        upd(1, 0, n - 1, v, l);
    }

    int get(int l, int r) {
        auto x = get(1, 0, n - 1, l, r);
        int res = max(x.pref, x.suf);
        return max(res, x.res);
    }
};

void solve() {
    int n;
    cin >> n;
    string s;
    cin >> s;
    segment_tree tr(2 * n + 2);
    for (int i = 0; i < n; ++i)
        tr.upd(i * 2 + 1, (s[i] == 'a' ? -1 : 1));
    int q;
    cin >> q;
    while (q--) {
        int t;
        cin >> t;
        if (t == 1) {
            int i;
            cin >> i;
            --i;
            s[i] = (s[i] == 'a' ? 'b' : 'a');
            tr.upd(i, s[i] == 'a' ? -1 : 1);
        } else {
            int l, r;
            cin >> l >> r;
            --l, --r;
            tr.upd(2 * l, 1);
            tr.upd(2 * r + 2, 1);
//            cout << tr.get(2 * l, 2 * r + 2) << endl;
            cout << (tr.get(2 * l, 2 * r + 2) >= 3 ? "NO\n" : "YES\n");
            tr.upd(2 * l, 0);
            tr.upd(2 * r + 2, 0);
        }
    }
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0); cout.tie(0);

    int tc = 1;
    // cin >> tc;
    for (int t = 1; t <= tc; ++t) {
        solve();
    }
}